Keep<T> class

Represents keeping an element at a specific index (no change).

Indicates that the element at oldIndex in the old list is the same as the element at newIndex in the new list.

Inheritance

Constructors

Keep(int oldIndex, int newIndex)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
newIndex int
The index of the element in the new list.
final
oldIndex int
The index of the element in the old list.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited