MatchedRouteResolution<T extends RouteUri> class final

A successfully matched route.

Inheritance

Constructors

MatchedRouteResolution({required RouteRequest request, required T route, int statusCode = 200, Map<String, List<String>> headers = const {}, RouteHydrationPayload? hydration})

Properties

hashCode int
The hash code for this object.
no setterinherited
headers Map<String, List<String>>
finalinherited
hydration RouteHydrationPayload?
Versioned, serializable loader data associated with this resolution.
finalinherited
request RouteRequest
finalinherited
route → T
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited