RedirectRouteResolution<T extends RouteUri> class
final
A redirect outcome that an HTTP or browser adapter can apply correctly.
- Inheritance
-
- Object
- RouteResolution<
T> - RedirectRouteResolution
Constructors
-
RedirectRouteResolution({required RouteRequest request, required Uri location, int statusCode = 302, Map<
String, List< headers = const {}, RouteHydrationPayload? hydration})String> >
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, List< String> > -
finalinherited
- hydration → RouteHydrationPayload?
-
Versioned, serializable loader data associated with this resolution.
finalinherited
- location → Uri
-
final
- request → RouteRequest
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
finalinherited
Methods
-
createRedirectRequest(
) → RouteRequest - Builds the follow-up request using RFC-compatible redirect semantics.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
supportedStatusCodes
→ const Set<
int>