onUpdate method

  1. @mustCallSuper
void onUpdate(
  1. covariant RouteTarget newRoute
)
inherited

Called when this route is updated with state from a new route instance.

When navigating to a route that already exists in the stack, instead of pushing a duplicate, this method is called to transfer state from the new route to the existing one. This enables scenarios like updating query parameters or refreshing data without rebuilding the widget.

Implementation

@mustCallSuper
void onUpdate(covariant RouteTarget newRoute) {}