RoutePattern class final
A parsed, validated URI path pattern.
Patterns use :name for one segment and ...:name for zero or more
segments. A pattern never contains a query or fragment.
Constructors
- RoutePattern(String source)
-
factory
Properties
- canonicalShape → String
-
no setter
- dynamicSegmentCount → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasRestParameter → bool
-
no setter
- minimumSegmentCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
segments
→ List<
RoutePatternSegment> -
final
- source → String
-
final
- staticSegmentCount → int
-
no setter
Methods
-
buildSegments(
{Map< String, String> pathParameters = const {}, Map<String, List< restParameters = const {}}) → List<String> >String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited