RoutePatternSegment class final

One immutable segment in a RoutePattern.

Properties

hashCode int
The hash code for this object.
no setterinherited
isParameter bool
no setter
isRest bool
no setter
kind RoutePatternSegmentKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Literal value or parameter name, depending on kind.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited