RouteResolutionCancelled class final
Control-flow exception used to stop a superseded route resolution.
- Implemented types
Constructors
- RouteResolutionCancelled([Object? reason])
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited