resultValue property
Object?
get
resultValue
The result value passed when this route was popped.
Implementation
Object? get resultValue => _resultValue;
The result value passed when this route was popped.
Object? get resultValue => _resultValue;