Keep<T> class
Represents keeping an element at a specific index (no change).
Indicates that the element at oldIndex in the old list is the same as the element at newIndex in the new list.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited